@@ -2,11 +2,12 @@
 
 """Test CLR <-> Python type conversions."""
 
+from __future__ import unicode_literals
 import System
 import pytest
-from Python.Test import ConversionTest
+from Python.Test import ConversionTest, UnicodeString
 
-from ._compat import indexbytes, long, unichr
+from ._compat import indexbytes, long, unichr, text_type, PY2, PY3
 
 
 def test_bool_conversion():
@@ -466,17 +467,6 @@ def test_double_conversion():
     with pytest.raises(TypeError):
         ConversionTest().DoubleField = None
 
-    with pytest.raises(OverflowError):
-        ConversionTest().DoubleField = 1.7976931348623159e308
-
-    with pytest.raises(OverflowError):
-        ConversionTest().DoubleField = -1.7976931348623159e308
-
-    with pytest.raises(OverflowError):
-        _ = System.Double(1.7976931348623159e308)
-
-    with pytest.raises(OverflowError):
-        _ = System.Double(-1.7976931348623159e308)
 
 
 def test_decimal_conversion():
@@ -546,6 +536,14 @@ def test_string_conversion():
 
     with pytest.raises(TypeError):
         ConversionTest().StringField = 1
+    
+    world = UnicodeString()
+    test_unicode_str = u"안녕"
+    assert test_unicode_str == text_type(world.value)
+    assert test_unicode_str == text_type(world.GetString())
+    # TODO: not sure what to do for Python 2 here (GH PR #670)
+    if PY3:
+        assert test_unicode_str == text_type(world)
 
 
 def test_interface_conversion():
@@ -641,6 +639,8 @@ def test_enum_conversion():
 
 def test_null_conversion():
     """Test null conversion."""
+    import System
+    
     ob = ConversionTest()
 
     ob.StringField = None
@@ -652,6 +652,10 @@ def test_null_conversion():
     ob.SpamField = None
     assert ob.SpamField is None
 
+    pi = 22/7
+    assert ob.Echo[System.Double](pi) == pi
+    assert ob.Echo[System.DateTime](None) is None
+
     # Primitive types and enums should not be set to null.
 
     with pytest.raises(TypeError):
