@@ -352,6 +352,26 @@ def test_clr_add_reference():
     with pytest.raises(FileNotFoundException):
         AddReference("somethingtotallysilly")
 
+def test_clr_get_clr_type():
+    """Test clr.GetClrType()."""
+    from clr import GetClrType
+    import System
+    from System import IComparable
+    from System import ArgumentException
+    assert GetClrType(System.String).FullName == "System.String"
+    comparable = GetClrType(IComparable)
+    assert comparable.FullName == "System.IComparable"
+    assert comparable.IsInterface
+    assert GetClrType(int).FullName == "System.Int32"
+    assert GetClrType(str).FullName == "System.String"
+    assert GetClrType(float).FullName == "System.Double"
+    dblarr = System.Array[System.Double]
+    assert GetClrType(dblarr).FullName == "System.Double[]"
+
+    with pytest.raises(TypeError):
+        GetClrType(1)
+    with pytest.raises(TypeError):
+        GetClrType("thiswillfail")
 
 def test_assembly_load_thread_safety():
     from Python.Test import ModuleTest
@@ -367,3 +387,9 @@ def test_assembly_load_thread_safety():
         from System.Collections.Generic import Dictionary
         _ = Dictionary[Guid, DateTime]()
     ModuleTest.JoinThreads()
+
+def test_assembly_load_recursion_bug():
+    """Test fix for recursion bug documented in #627"""
+    from System.Configuration import ConfigurationManager
+    content = dir(ConfigurationManager)
+    assert len(content) > 5, content
